jdk/src/share/classes/sun/security/ssl/Handshaker.java
changeset 18554 d2f655022d2d
parent 18283 f842a42076b9
child 19823 f0fd09e20528
child 22309 1990211a42e5
--- a/jdk/src/share/classes/sun/security/ssl/Handshaker.java	Tue Jun 25 21:03:08 2013 -0700
+++ b/jdk/src/share/classes/sun/security/ssl/Handshaker.java	Wed Jun 26 06:32:40 2013 -0700
@@ -187,14 +187,14 @@
                     "sun.security.ssl.allowLegacyHelloMessages", true);
 
     // To prevent the TLS renegotiation issues, by setting system property
     // "jdk.tls.rejectClientInitializedRenego" to true, applications in server
     // side can disable all client initiated SSL renegotiations regardless
     // of the support of TLS protocols.
     //
     // By default, allow client initiated renegotiations.
     static final boolean rejectClientInitiatedRenego =
             Debug.getBooleanProperty(
-                "jdk.tls.rejectClientInitializedRenego", false);
+                "jdk.tls.rejectClientInitiatedRenegotiation", false);
 
     // need to dispose the object when it is invalidated
     boolean invalidated;
@@ -187,14 +187,14 @@
 
     // To prevent the TLS renegotiation issues, by setting system property
-    // "jdk.tls.rejectClientInitializedRenego" to true, applications in server
-    // side can disable all client initiated SSL renegotiations regardless
-    // of the support of TLS protocols.
+    // "jdk.tls.rejectClientInitiatedRenegotiation" to true, applications in
+    // server side can disable all client initiated SSL renegotiations
+    // regardless of the support of TLS protocols.
     //
     // By default, allow client initiated renegotiations.